@@ -32,7 +32,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.51';
+our $VERSION = '2.52';
 
 =head1 SYNOPSIS
 
@@ -752,8 +752,8 @@ sub process_lines {
     my $self = shift;
     my $line = shift;
 
-    $self->check_meta($line);
-    return if $line =~ m/^#/;
+    #$self->check_meta($line);
+    #return if $line =~ m/^#/;
 
     $DB::single=2;
 
@@ -771,6 +771,10 @@ sub process_lines {
         push(@{$self->jobref}, []) if $self->serial;
     }
 
+    $DB::single=2;
+    $self->check_meta($line);
+    return if $line =~ m/^#/;
+
     if($self->has_cmd){
         $self->add_cmd($line);
         $self->add_batch($line);
@@ -905,8 +909,13 @@ sub process_batch{
     my $self = shift;
     my($cmdfile, $slurmfile, $slurmsubmit, $fh, $command);
 
-    $self->cmdfile($self->outdir."/".$self->jobname."_".$self->batch_counter.".in");
-    $self->slurmfile($self->outdir."/".$self->jobname."_".$self->batch_counter.".sh");
+    my $counter = $self->batch_counter;
+    $counter = sprintf ("%03d", $counter);
+
+    #$self->cmdfile($self->outdir."/".$self->jobname."_".$self->batch_counter.".in");
+    #$self->slurmfile($self->outdir."/".$self->jobname."_".$self->batch_counter.".sh");
+    $self->cmdfile($self->outdir."/$counter"."_".$self->jobname.".in");
+    $self->slurmfile($self->outdir."/$counter"."_".$self->jobname.".sh");
 
     $fh = IO::File->new( $self->cmdfile, q{>} ) or print "Error opening file  ".$self->cmdfile."  ".$!;
 
@@ -923,13 +932,13 @@ sub process_batch{
     $DB::single=2;
 
     $self->template->process($self->template_file,
-        { JOBNAME => $self->jobname."_".$self->batch_counter,
+        { JOBNAME => $counter."_".$self->jobname,
             USER => $self->user,
             NODE => $self->node,
             CPU => $self->cpus_per_task,
             PARTITION => $self->partition,
             AFTEROK => $ok,
-            OUT => $self->logdir."/".$self->jobname."_".$self->batch_counter.".log",
+            OUT => $self->logdir."/$counter"."_".$self->jobname.".log",
             MODULE => $self->module,
             self => $self,
             COMMAND => $command },
@@ -958,21 +967,24 @@ sub process_batch_command {
     #Need to get absolute path going on...
     #$self->cmdfile($self->jobname."_batch".$self->batch_counter.".in");
 
+    my $counter = $self->batch_counter;
+    $counter = sprintf ("%03d", $counter);
+
     if($self->has_custom_command){
         $command = "cd ".getcwd()."\n";
-        $command .= $self->custom_command." --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
+        $command .= $self->custom_command." --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname $counter"."_".$self->jobname;
     }
     elsif($self->use_gnuparallel){
         $command = "cd ".getcwd()."\n";
-        $command .= "cat ".$self->cmdfile." | parallelparser.pl | parallel --joblog ".$self->outdir."/main.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter." --seq {#}"."\n";
+        $command .= "cat ".$self->cmdfile." | parallelparser.pl | parallel --joblog ".$self->outdir."/main.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir ".$self->outdir." --logname $counter"."_".$self->jobname." --seq {#}"."\n";
     }
     elsif($self->use_threads){
         $command = "cd ".getcwd()."\n"; #Go back to the working directory just to be safe
-        $command .= "paralellrunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
+        $command .= "paralellrunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname $counter"."_".$self->jobname;
     }
     elsif($self->use_processes){
         $command = "cd ".getcwd()."\n";
-        $command .= "mcerunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
+        $command .= "mcerunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname $counter"."_".$self->jobname;
     }
     else{
         die print "None of the job processes were chosen!\n";
